<!DOCTYPE html>
<html>
<head>
    <meta name="viewport" content="width=device-width,initial-scale=1">
    <title>{% block title %}{{ CONFIG.site_name }}{% endblock %}</title>
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/normalize.css" media="screen">
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/main.css" media="screen">
    <link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/selectize.js/0.12.6/css/selectize.css" media="screen">
    <script defer src="https://use.fontawesome.com/releases/v5.8.1/js/all.js" integrity="sha384-g5uSoOSBd7KkhAMlnQILrecXvzst9TdC09/VM+pjDTCM+1il8RHz5fKANTFFb+gQ" crossorigin="anonymous"></script>
    <link href="https://fonts.googleapis.com/css?family=Lato:300" rel="stylesheet">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.4.0/jquery.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/selectize.js/0.12.6/js/standalone/selectize.min.js"></script>
</head>
<body class="{% block body_class %}{% endblock %}">

{% block content %}{% endblock %}

<div class="footer">
    <p>
        By Peter Jaric and Jonatan Heyman.
    </p>
</div>
</body>
</html>
